@@ -24,10 +24,8 @@
 # along with the R-package decisionSupport.  If not, see <http://www.gnu.org/licenses/>.
 #
 ##############################################################################################
-#' @importFrom testthat test_check
-
 
 library(testthat)
-library(decisionSupport)
+#library(decisionSupport)
 
 test_check("decisionSupport")
